==> dialog_pp_flutter-1.0.2.tar.gz: example/lib/main.dart <==
import 'dart:async';

import 'package:dialog_pp_flutter/dialog_pp_flutter.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:get/get.dart';
import 'package:get/get_navigation/src/root/get_material_app.dart';

Future<void> main() async {
  await PPDialog.newVersionCode();
  runApp(ScreenUtilInit(
      builder: (context, child) => const GetMaterialApp(
            home: MYYYYY(),
          )));
}

class MYYYYY extends StatefulWidget {
  const MYYYYY({Key? key}) : super(key: key);

  @override
  State<MYYYYY> createState() => _MYYYYYState();
}

class _MYYYYYState extends State<MYYYYY> {
  @override
  void initState() {
    // TODO: implement initState
    super.initState();

    Future.delayed(const Duration(seconds: 3), () {
      Get.to(const MyApp());
    });
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(),
    );
  }
}

class MyApp extends StatefulWidget {
  const MyApp({Key? key}) : super(key: key);

  @override
  State<MyApp> createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  @override
  void initState() {
    super.initState();
    Future.delayed(const Duration(seconds: 0), () {
      checkVersion();
    });
  }

  checkVersion() async {}

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      // drawer: PPDialog.drawerScreen(
      //     appLogo: "assets/dialogs_assets/playstore.png",
      //     privacyPolicy:
      //         "https://sites.google.com/view/bitlinksprivacypolicy/home",
      //     feedbackEmailId: "mailto:bitlinks.llc@gmail.com",
      //     emailSubject: "Feedback on Pakistan IPTV Links m3u Playlists",
      //     emailMessage:
      //         "Hi,\n\n\nYour Feedback Pakistan IPTV Links m3u Playlists! I would like to give you some feedback:"),
      appBar: AppBar(
        title: const Text('Plugin example app'),
      ),
      body: Center(
        child: InkWell(
            onTap: () {
              PPDialog.exitDialog(
                  mediumNative: Container(
                    alignment: Alignment.center,
                    height: 170.h,
                    color: Colors.green[200],
                    child: Text("Medium Size Native Ad"),
                  ),
                  appLogo: '');
            },
            child: const Text('dsfdsfdsfn\ndsfdsf\ndfsgdsfds\ndfdsfdsfdsfds')),
      ),
    );
  }
}

==> dialog_pp_flutter-1.0.4.tar.gz: example/lib/main.dart <==
import 'dart:async';

import 'package:dialog_pp_flutter/dialog_pp_flutter.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:get/get.dart';
import 'package:get/get_navigation/src/root/get_material_app.dart';

Future<void> main() async {
  await PPDialog.newVersionCode();
  runApp(ScreenUtilInit(
      builder: (context, child) =>
      const GetMaterialApp(
        home: MYYYYY(),
      )));
}

class MYYYYY extends StatefulWidget {
  const MYYYYY({Key? key}) : super(key: key);

  @override
  State<MYYYYY> createState() => _MYYYYYState();
}

class _MYYYYYState extends State<MYYYYY> {
  @override
  void initState() {
    // TODO: implement initState
    super.initState();

    Future.delayed(const Duration(seconds: 3), () {
      Get.to(const MyApp());
    });
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(),
    );
  }
}

class MyApp extends StatefulWidget {
  const MyApp({Key? key}) : super(key: key);

  @override
  State<MyApp> createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  @override
  void initState() {
    super.initState();
    Future.delayed(const Duration(seconds: 0), () {
      checkVersion();
    });
  }

  checkVersion() async {}

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      // drawer: PPDialog.drawerScreen(
      //     appLogo: "assets/dialogs_assets/playstore.png",
      //     privacyPolicy:
      //         "https://sites.google.com/view/bitlinksprivacypolicy/home",
      //     feedbackEmailId: "mailto:bitlinks.llc@gmail.com",
      //     emailSubject: "Feedback on Pakistan IPTV Links m3u Playlists",
      //     emailMessage:
      //         "Hi,\n\n\nYour Feedback Pakistan IPTV Links m3u Playlists! I would like to give you some feedback:"),
      appBar: AppBar(
        title: const Text('Plugin example app'),
      ),
      body: Center(
        child: InkWell(
            onTap: () {
              PPDialog.rateDialogCustom(context, logoApp: )
            },
            child: const Text('dsfdsfdsfn\ndsfdsf\ndfsgdsfds\ndfdsfdsfdsfds')),
      ),
    );
  }
}
